# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: devolo_idl_proto_plcnetapi_setuserdevicename.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='devolo_idl_proto_plcnetapi_setuserdevicename.proto',
  package='plcnet.api',
  syntax='proto3',
  serialized_pb=_b('\n2devolo_idl_proto_plcnetapi_setuserdevicename.proto\x12\nplcnet.api\"B\n\x11SetUserDeviceName\x12\x13\n\x0bmac_address\x18\x01 \x01(\t\x12\x18\n\x10user_device_name\x18\x02 \x01(\t\"\xe2\x01\n\x19SetUserDeviceNameResponse\x12<\n\x06result\x18\x01 \x01(\x0e\x32,.plcnet.api.SetUserDeviceNameResponse.Result\"\x86\x01\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x13\n\x0fMACADDR_INVALID\x10\x01\x12\x13\n\x0fMACADDR_UNKNOWN\x10\x02\x12\x17\n\x13\x44\x45VICE_NAME_INVALID\x10\x03\x12\x18\n\x13\x43OMMUNICATION_ERROR\x10\xfe\x01\x12\x12\n\rUNKNOWN_ERROR\x10\xff\x01\x42\x0e\n\x06plcnetB\x04nameb\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_SETUSERDEVICENAMERESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='plcnet.api.SetUserDeviceNameResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MACADDR_INVALID', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MACADDR_UNKNOWN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_NAME_INVALID', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMUNICATION_ERROR', index=4, number=254,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR', index=5, number=255,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=227,
  serialized_end=361,
)
_sym_db.RegisterEnumDescriptor(_SETUSERDEVICENAMERESPONSE_RESULT)


_SETUSERDEVICENAME = _descriptor.Descriptor(
  name='SetUserDeviceName',
  full_name='plcnet.api.SetUserDeviceName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mac_address', full_name='plcnet.api.SetUserDeviceName.mac_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_device_name', full_name='plcnet.api.SetUserDeviceName.user_device_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=132,
)


_SETUSERDEVICENAMERESPONSE = _descriptor.Descriptor(
  name='SetUserDeviceNameResponse',
  full_name='plcnet.api.SetUserDeviceNameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='plcnet.api.SetUserDeviceNameResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SETUSERDEVICENAMERESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=361,
)

_SETUSERDEVICENAMERESPONSE.fields_by_name['result'].enum_type = _SETUSERDEVICENAMERESPONSE_RESULT
_SETUSERDEVICENAMERESPONSE_RESULT.containing_type = _SETUSERDEVICENAMERESPONSE
DESCRIPTOR.message_types_by_name['SetUserDeviceName'] = _SETUSERDEVICENAME
DESCRIPTOR.message_types_by_name['SetUserDeviceNameResponse'] = _SETUSERDEVICENAMERESPONSE

SetUserDeviceName = _reflection.GeneratedProtocolMessageType('SetUserDeviceName', (_message.Message,), dict(
  DESCRIPTOR = _SETUSERDEVICENAME,
  __module__ = 'devolo_idl_proto_plcnetapi_setuserdevicename_pb2'
  # @@protoc_insertion_point(class_scope:plcnet.api.SetUserDeviceName)
  ))
_sym_db.RegisterMessage(SetUserDeviceName)

SetUserDeviceNameResponse = _reflection.GeneratedProtocolMessageType('SetUserDeviceNameResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETUSERDEVICENAMERESPONSE,
  __module__ = 'devolo_idl_proto_plcnetapi_setuserdevicename_pb2'
  # @@protoc_insertion_point(class_scope:plcnet.api.SetUserDeviceNameResponse)
  ))
_sym_db.RegisterMessage(SetUserDeviceNameResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\006plcnetB\004name'))
# @@protoc_insertion_point(module_scope)
