# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: devolo_idl_proto_deviceapi_ledsettings.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='devolo_idl_proto_deviceapi_ledsettings.proto',
  package='device.api',
  syntax='proto3',
  serialized_pb=_b('\n,devolo_idl_proto_deviceapi_ledsettings.proto\x12\ndevice.api\"i\n\x0eLedSettingsGet\x12\x32\n\x05state\x18\x01 \x01(\x0e\x32#.device.api.LedSettingsGet.Ledstate\"#\n\x08Ledstate\x12\n\n\x06LED_ON\x10\x00\x12\x0b\n\x07LED_OFF\x10\x01\"i\n\x0eLedSettingsSet\x12\x32\n\x05state\x18\x01 \x01(\x0e\x32#.device.api.LedSettingsSet.Ledstate\"#\n\x08Ledstate\x12\n\n\x06LED_ON\x10\x00\x12\x0b\n\x07LED_OFF\x10\x01\"~\n\x16LedSettingsSetResponse\x12\x39\n\x06result\x18\x01 \x01(\x0e\x32).device.api.LedSettingsSetResponse.Result\")\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x12\n\rUNKNOWN_ERROR\x10\xff\x01\x42\x0e\n\x06\x64\x65viceB\x04ledsb\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_LEDSETTINGSGET_LEDSTATE = _descriptor.EnumDescriptor(
  name='Ledstate',
  full_name='device.api.LedSettingsGet.Ledstate',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LED_ON', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LED_OFF', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=130,
  serialized_end=165,
)
_sym_db.RegisterEnumDescriptor(_LEDSETTINGSGET_LEDSTATE)

_LEDSETTINGSSET_LEDSTATE = _descriptor.EnumDescriptor(
  name='Ledstate',
  full_name='device.api.LedSettingsSet.Ledstate',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LED_ON', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LED_OFF', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=130,
  serialized_end=165,
)
_sym_db.RegisterEnumDescriptor(_LEDSETTINGSSET_LEDSTATE)

_LEDSETTINGSSETRESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='device.api.LedSettingsSetResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR', index=1, number=255,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=359,
  serialized_end=400,
)
_sym_db.RegisterEnumDescriptor(_LEDSETTINGSSETRESPONSE_RESULT)


_LEDSETTINGSGET = _descriptor.Descriptor(
  name='LedSettingsGet',
  full_name='device.api.LedSettingsGet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='device.api.LedSettingsGet.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LEDSETTINGSGET_LEDSTATE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=165,
)


_LEDSETTINGSSET = _descriptor.Descriptor(
  name='LedSettingsSet',
  full_name='device.api.LedSettingsSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='device.api.LedSettingsSet.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LEDSETTINGSSET_LEDSTATE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=272,
)


_LEDSETTINGSSETRESPONSE = _descriptor.Descriptor(
  name='LedSettingsSetResponse',
  full_name='device.api.LedSettingsSetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='device.api.LedSettingsSetResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LEDSETTINGSSETRESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=274,
  serialized_end=400,
)

_LEDSETTINGSGET.fields_by_name['state'].enum_type = _LEDSETTINGSGET_LEDSTATE
_LEDSETTINGSGET_LEDSTATE.containing_type = _LEDSETTINGSGET
_LEDSETTINGSSET.fields_by_name['state'].enum_type = _LEDSETTINGSSET_LEDSTATE
_LEDSETTINGSSET_LEDSTATE.containing_type = _LEDSETTINGSSET
_LEDSETTINGSSETRESPONSE.fields_by_name['result'].enum_type = _LEDSETTINGSSETRESPONSE_RESULT
_LEDSETTINGSSETRESPONSE_RESULT.containing_type = _LEDSETTINGSSETRESPONSE
DESCRIPTOR.message_types_by_name['LedSettingsGet'] = _LEDSETTINGSGET
DESCRIPTOR.message_types_by_name['LedSettingsSet'] = _LEDSETTINGSSET
DESCRIPTOR.message_types_by_name['LedSettingsSetResponse'] = _LEDSETTINGSSETRESPONSE

LedSettingsGet = _reflection.GeneratedProtocolMessageType('LedSettingsGet', (_message.Message,), dict(
  DESCRIPTOR = _LEDSETTINGSGET,
  __module__ = 'devolo_idl_proto_deviceapi_ledsettings_pb2'
  # @@protoc_insertion_point(class_scope:device.api.LedSettingsGet)
  ))
_sym_db.RegisterMessage(LedSettingsGet)

LedSettingsSet = _reflection.GeneratedProtocolMessageType('LedSettingsSet', (_message.Message,), dict(
  DESCRIPTOR = _LEDSETTINGSSET,
  __module__ = 'devolo_idl_proto_deviceapi_ledsettings_pb2'
  # @@protoc_insertion_point(class_scope:device.api.LedSettingsSet)
  ))
_sym_db.RegisterMessage(LedSettingsSet)

LedSettingsSetResponse = _reflection.GeneratedProtocolMessageType('LedSettingsSetResponse', (_message.Message,), dict(
  DESCRIPTOR = _LEDSETTINGSSETRESPONSE,
  __module__ = 'devolo_idl_proto_deviceapi_ledsettings_pb2'
  # @@protoc_insertion_point(class_scope:device.api.LedSettingsSetResponse)
  ))
_sym_db.RegisterMessage(LedSettingsSetResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\006deviceB\004leds'))
# @@protoc_insertion_point(module_scope)
