# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: updatefirmware.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='updatefirmware.proto',
  package='device.api',
  syntax='proto3',
  serialized_options=_b('\n\006deviceB\006update'),
  serialized_pb=_b('\n\x14updatefirmware.proto\x12\ndevice.api\"\xb9\x01\n\x13UpdateFirmwareCheck\x12\x36\n\x06result\x18\x01 \x01(\x0e\x32&.device.api.UpdateFirmwareCheck.Result\x12\x1c\n\x14new_firmware_version\x18\x02 \x01(\t\"L\n\x06Result\x12\x14\n\x10UPDATE_AVAILABLE\x10\x00\x12\x18\n\x14UPDATE_NOT_AVAILABLE\x10\x01\x12\x12\n\rUNKNOWN_ERROR\x10\xff\x01\"\x99\x01\n\x13UpdateFirmwareStart\x12\x36\n\x06result\x18\x01 \x01(\x0e\x32&.device.api.UpdateFirmwareStart.Result\"J\n\x06Result\x12\x12\n\x0eUPDATE_STARTED\x10\x00\x12\x18\n\x14UPDATE_NOT_AVAILABLE\x10\x01\x12\x12\n\rUNKNOWN_ERROR\x10\xff\x01\x42\x10\n\x06\x64\x65viceB\x06updateb\x06proto3')
)



_UPDATEFIRMWARECHECK_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='device.api.UpdateFirmwareCheck.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UPDATE_AVAILABLE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE_NOT_AVAILABLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR', index=2, number=255,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=146,
  serialized_end=222,
)
_sym_db.RegisterEnumDescriptor(_UPDATEFIRMWARECHECK_RESULT)

_UPDATEFIRMWARESTART_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='device.api.UpdateFirmwareStart.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UPDATE_STARTED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE_NOT_AVAILABLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR', index=2, number=255,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=304,
  serialized_end=378,
)
_sym_db.RegisterEnumDescriptor(_UPDATEFIRMWARESTART_RESULT)


_UPDATEFIRMWARECHECK = _descriptor.Descriptor(
  name='UpdateFirmwareCheck',
  full_name='device.api.UpdateFirmwareCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='device.api.UpdateFirmwareCheck.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_firmware_version', full_name='device.api.UpdateFirmwareCheck.new_firmware_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UPDATEFIRMWARECHECK_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37,
  serialized_end=222,
)


_UPDATEFIRMWARESTART = _descriptor.Descriptor(
  name='UpdateFirmwareStart',
  full_name='device.api.UpdateFirmwareStart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='device.api.UpdateFirmwareStart.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UPDATEFIRMWARESTART_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=378,
)

_UPDATEFIRMWARECHECK.fields_by_name['result'].enum_type = _UPDATEFIRMWARECHECK_RESULT
_UPDATEFIRMWARECHECK_RESULT.containing_type = _UPDATEFIRMWARECHECK
_UPDATEFIRMWARESTART.fields_by_name['result'].enum_type = _UPDATEFIRMWARESTART_RESULT
_UPDATEFIRMWARESTART_RESULT.containing_type = _UPDATEFIRMWARESTART
DESCRIPTOR.message_types_by_name['UpdateFirmwareCheck'] = _UPDATEFIRMWARECHECK
DESCRIPTOR.message_types_by_name['UpdateFirmwareStart'] = _UPDATEFIRMWARESTART
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UpdateFirmwareCheck = _reflection.GeneratedProtocolMessageType('UpdateFirmwareCheck', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEFIRMWARECHECK,
  __module__ = 'updatefirmware_pb2'
  # @@protoc_insertion_point(class_scope:device.api.UpdateFirmwareCheck)
  ))
_sym_db.RegisterMessage(UpdateFirmwareCheck)

UpdateFirmwareStart = _reflection.GeneratedProtocolMessageType('UpdateFirmwareStart', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEFIRMWARESTART,
  __module__ = 'updatefirmware_pb2'
  # @@protoc_insertion_point(class_scope:device.api.UpdateFirmwareStart)
  ))
_sym_db.RegisterMessage(UpdateFirmwareStart)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
