# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: devolo_idl_proto_plcnetapi_getnetworkoverview.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='devolo_idl_proto_plcnetapi_getnetworkoverview.proto',
  package='plcnet.api',
  syntax='proto3',
  serialized_pb=_b('\n3devolo_idl_proto_plcnetapi_getnetworkoverview.proto\x12\nplcnet.api\"\xd5\x06\n\x12GetNetworkOverview\x12>\n\x07network\x18\x01 \x01(\x0b\x32-.plcnet.api.GetNetworkOverview.LogicalNetwork\x1a\x96\x04\n\x06\x44\x65vice\x12\x14\n\x0cproduct_name\x18\x01 \x01(\t\x12\x12\n\nproduct_id\x18\x02 \x01(\t\x12\x18\n\x10\x66riendly_version\x18\x03 \x01(\t\x12\x14\n\x0c\x66ull_version\x18\x04 \x01(\t\x12\x18\n\x10user_device_name\x18\x05 \x01(\t\x12\x19\n\x11user_network_name\x18\x06 \x01(\t\x12\x13\n\x0bmac_address\x18\x07 \x01(\t\x12@\n\x08topology\x18\x08 \x01(\x0e\x32..plcnet.api.GetNetworkOverview.Device.Topology\x12\x44\n\ntechnology\x18\t \x01(\x0e\x32\x30.plcnet.api.GetNetworkOverview.Device.Technology\x12\x17\n\x0f\x62ridged_devices\x18\n \x03(\t\x12\x14\n\x0cipv4_address\x18\x0b \x01(\t\x12\x1a\n\x12\x61ttached_to_router\x18\x0c \x01(\x08\"7\n\x08Topology\x12\x14\n\x10UNKNOWN_TOPOLOGY\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\n\n\x06REMOTE\x10\x02\"\\\n\nTechnology\x12\x16\n\x12UNKNOWN_TECHNOLOGY\x10\x00\x12\x14\n\x10HPAV_THUNDERBOLT\x10\x03\x12\x10\n\x0cHPAV_PANTHER\x10\x04\x12\x0e\n\nGHN_SPIRIT\x10\x07\x1a^\n\x08\x44\x61taRate\x12\x18\n\x10mac_address_from\x18\x01 \x01(\t\x12\x16\n\x0emac_address_to\x18\x02 \x01(\t\x12\x0f\n\x07tx_rate\x18\x03 \x01(\x01\x12\x0f\n\x07rx_rate\x18\x04 \x01(\x01\x1a\x85\x01\n\x0eLogicalNetwork\x12\x36\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32%.plcnet.api.GetNetworkOverview.Device\x12;\n\ndata_rates\x18\x02 \x03(\x0b\x32\'.plcnet.api.GetNetworkOverview.DataRateB\r\n\x06plcnetB\x03netb\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_GETNETWORKOVERVIEW_DEVICE_TOPOLOGY = _descriptor.EnumDescriptor(
  name='Topology',
  full_name='plcnet.api.GetNetworkOverview.Device.Topology',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_TOPOLOGY', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCAL', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REMOTE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=540,
  serialized_end=595,
)
_sym_db.RegisterEnumDescriptor(_GETNETWORKOVERVIEW_DEVICE_TOPOLOGY)

_GETNETWORKOVERVIEW_DEVICE_TECHNOLOGY = _descriptor.EnumDescriptor(
  name='Technology',
  full_name='plcnet.api.GetNetworkOverview.Device.Technology',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_TECHNOLOGY', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HPAV_THUNDERBOLT', index=1, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HPAV_PANTHER', index=2, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GHN_SPIRIT', index=3, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=597,
  serialized_end=689,
)
_sym_db.RegisterEnumDescriptor(_GETNETWORKOVERVIEW_DEVICE_TECHNOLOGY)


_GETNETWORKOVERVIEW_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='plcnet.api.GetNetworkOverview.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='product_name', full_name='plcnet.api.GetNetworkOverview.Device.product_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='product_id', full_name='plcnet.api.GetNetworkOverview.Device.product_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='friendly_version', full_name='plcnet.api.GetNetworkOverview.Device.friendly_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='full_version', full_name='plcnet.api.GetNetworkOverview.Device.full_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_device_name', full_name='plcnet.api.GetNetworkOverview.Device.user_device_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_network_name', full_name='plcnet.api.GetNetworkOverview.Device.user_network_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mac_address', full_name='plcnet.api.GetNetworkOverview.Device.mac_address', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='topology', full_name='plcnet.api.GetNetworkOverview.Device.topology', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='technology', full_name='plcnet.api.GetNetworkOverview.Device.technology', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bridged_devices', full_name='plcnet.api.GetNetworkOverview.Device.bridged_devices', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ipv4_address', full_name='plcnet.api.GetNetworkOverview.Device.ipv4_address', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attached_to_router', full_name='plcnet.api.GetNetworkOverview.Device.attached_to_router', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETNETWORKOVERVIEW_DEVICE_TOPOLOGY,
    _GETNETWORKOVERVIEW_DEVICE_TECHNOLOGY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=689,
)

_GETNETWORKOVERVIEW_DATARATE = _descriptor.Descriptor(
  name='DataRate',
  full_name='plcnet.api.GetNetworkOverview.DataRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mac_address_from', full_name='plcnet.api.GetNetworkOverview.DataRate.mac_address_from', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mac_address_to', full_name='plcnet.api.GetNetworkOverview.DataRate.mac_address_to', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tx_rate', full_name='plcnet.api.GetNetworkOverview.DataRate.tx_rate', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rx_rate', full_name='plcnet.api.GetNetworkOverview.DataRate.rx_rate', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=785,
)

_GETNETWORKOVERVIEW_LOGICALNETWORK = _descriptor.Descriptor(
  name='LogicalNetwork',
  full_name='plcnet.api.GetNetworkOverview.LogicalNetwork',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='plcnet.api.GetNetworkOverview.LogicalNetwork.devices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data_rates', full_name='plcnet.api.GetNetworkOverview.LogicalNetwork.data_rates', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=921,
)

_GETNETWORKOVERVIEW = _descriptor.Descriptor(
  name='GetNetworkOverview',
  full_name='plcnet.api.GetNetworkOverview',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='network', full_name='plcnet.api.GetNetworkOverview.network', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GETNETWORKOVERVIEW_DEVICE, _GETNETWORKOVERVIEW_DATARATE, _GETNETWORKOVERVIEW_LOGICALNETWORK, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=921,
)

_GETNETWORKOVERVIEW_DEVICE.fields_by_name['topology'].enum_type = _GETNETWORKOVERVIEW_DEVICE_TOPOLOGY
_GETNETWORKOVERVIEW_DEVICE.fields_by_name['technology'].enum_type = _GETNETWORKOVERVIEW_DEVICE_TECHNOLOGY
_GETNETWORKOVERVIEW_DEVICE.containing_type = _GETNETWORKOVERVIEW
_GETNETWORKOVERVIEW_DEVICE_TOPOLOGY.containing_type = _GETNETWORKOVERVIEW_DEVICE
_GETNETWORKOVERVIEW_DEVICE_TECHNOLOGY.containing_type = _GETNETWORKOVERVIEW_DEVICE
_GETNETWORKOVERVIEW_DATARATE.containing_type = _GETNETWORKOVERVIEW
_GETNETWORKOVERVIEW_LOGICALNETWORK.fields_by_name['devices'].message_type = _GETNETWORKOVERVIEW_DEVICE
_GETNETWORKOVERVIEW_LOGICALNETWORK.fields_by_name['data_rates'].message_type = _GETNETWORKOVERVIEW_DATARATE
_GETNETWORKOVERVIEW_LOGICALNETWORK.containing_type = _GETNETWORKOVERVIEW
_GETNETWORKOVERVIEW.fields_by_name['network'].message_type = _GETNETWORKOVERVIEW_LOGICALNETWORK
DESCRIPTOR.message_types_by_name['GetNetworkOverview'] = _GETNETWORKOVERVIEW

GetNetworkOverview = _reflection.GeneratedProtocolMessageType('GetNetworkOverview', (_message.Message,), dict(

  Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), dict(
    DESCRIPTOR = _GETNETWORKOVERVIEW_DEVICE,
    __module__ = 'devolo_idl_proto_plcnetapi_getnetworkoverview_pb2'
    # @@protoc_insertion_point(class_scope:plcnet.api.GetNetworkOverview.Device)
    ))
  ,

  DataRate = _reflection.GeneratedProtocolMessageType('DataRate', (_message.Message,), dict(
    DESCRIPTOR = _GETNETWORKOVERVIEW_DATARATE,
    __module__ = 'devolo_idl_proto_plcnetapi_getnetworkoverview_pb2'
    # @@protoc_insertion_point(class_scope:plcnet.api.GetNetworkOverview.DataRate)
    ))
  ,

  LogicalNetwork = _reflection.GeneratedProtocolMessageType('LogicalNetwork', (_message.Message,), dict(
    DESCRIPTOR = _GETNETWORKOVERVIEW_LOGICALNETWORK,
    __module__ = 'devolo_idl_proto_plcnetapi_getnetworkoverview_pb2'
    # @@protoc_insertion_point(class_scope:plcnet.api.GetNetworkOverview.LogicalNetwork)
    ))
  ,
  DESCRIPTOR = _GETNETWORKOVERVIEW,
  __module__ = 'devolo_idl_proto_plcnetapi_getnetworkoverview_pb2'
  # @@protoc_insertion_point(class_scope:plcnet.api.GetNetworkOverview)
  ))
_sym_db.RegisterMessage(GetNetworkOverview)
_sym_db.RegisterMessage(GetNetworkOverview.Device)
_sym_db.RegisterMessage(GetNetworkOverview.DataRate)
_sym_db.RegisterMessage(GetNetworkOverview.LogicalNetwork)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\006plcnetB\003net'))
# @@protoc_insertion_point(module_scope)
