# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: devolo_idl_proto_plcnetapi_identifydevice.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='devolo_idl_proto_plcnetapi_identifydevice.proto',
  package='plcnet.api',
  syntax='proto3',
  serialized_pb=_b('\n/devolo_idl_proto_plcnetapi_identifydevice.proto\x12\nplcnet.api\"*\n\x13IdentifyDeviceStart\x12\x13\n\x0bmac_address\x18\x01 \x01(\t\")\n\x12IdentifyDeviceStop\x12\x13\n\x0bmac_address\x18\x01 \x01(\t\"\xc2\x01\n\x16IdentifyDeviceResponse\x12\x39\n\x06result\x18\x01 \x01(\x0e\x32).plcnet.api.IdentifyDeviceResponse.Result\"m\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x13\n\x0fMACADDR_INVALID\x10\x01\x12\x13\n\x0fMACADDR_UNKNOWN\x10\x02\x12\x18\n\x13\x43OMMUNICATION_ERROR\x10\xfe\x01\x12\x12\n\rUNKNOWN_ERROR\x10\xff\x01\x42\x12\n\x06plcnetB\x08identityb\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_IDENTIFYDEVICERESPONSE_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='plcnet.api.IdentifyDeviceResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MACADDR_INVALID', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MACADDR_UNKNOWN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMUNICATION_ERROR', index=3, number=254,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ERROR', index=4, number=255,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=236,
  serialized_end=345,
)
_sym_db.RegisterEnumDescriptor(_IDENTIFYDEVICERESPONSE_RESULT)


_IDENTIFYDEVICESTART = _descriptor.Descriptor(
  name='IdentifyDeviceStart',
  full_name='plcnet.api.IdentifyDeviceStart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mac_address', full_name='plcnet.api.IdentifyDeviceStart.mac_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=105,
)


_IDENTIFYDEVICESTOP = _descriptor.Descriptor(
  name='IdentifyDeviceStop',
  full_name='plcnet.api.IdentifyDeviceStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mac_address', full_name='plcnet.api.IdentifyDeviceStop.mac_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=148,
)


_IDENTIFYDEVICERESPONSE = _descriptor.Descriptor(
  name='IdentifyDeviceResponse',
  full_name='plcnet.api.IdentifyDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='plcnet.api.IdentifyDeviceResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IDENTIFYDEVICERESPONSE_RESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=345,
)

_IDENTIFYDEVICERESPONSE.fields_by_name['result'].enum_type = _IDENTIFYDEVICERESPONSE_RESULT
_IDENTIFYDEVICERESPONSE_RESULT.containing_type = _IDENTIFYDEVICERESPONSE
DESCRIPTOR.message_types_by_name['IdentifyDeviceStart'] = _IDENTIFYDEVICESTART
DESCRIPTOR.message_types_by_name['IdentifyDeviceStop'] = _IDENTIFYDEVICESTOP
DESCRIPTOR.message_types_by_name['IdentifyDeviceResponse'] = _IDENTIFYDEVICERESPONSE

IdentifyDeviceStart = _reflection.GeneratedProtocolMessageType('IdentifyDeviceStart', (_message.Message,), dict(
  DESCRIPTOR = _IDENTIFYDEVICESTART,
  __module__ = 'devolo_idl_proto_plcnetapi_identifydevice_pb2'
  # @@protoc_insertion_point(class_scope:plcnet.api.IdentifyDeviceStart)
  ))
_sym_db.RegisterMessage(IdentifyDeviceStart)

IdentifyDeviceStop = _reflection.GeneratedProtocolMessageType('IdentifyDeviceStop', (_message.Message,), dict(
  DESCRIPTOR = _IDENTIFYDEVICESTOP,
  __module__ = 'devolo_idl_proto_plcnetapi_identifydevice_pb2'
  # @@protoc_insertion_point(class_scope:plcnet.api.IdentifyDeviceStop)
  ))
_sym_db.RegisterMessage(IdentifyDeviceStop)

IdentifyDeviceResponse = _reflection.GeneratedProtocolMessageType('IdentifyDeviceResponse', (_message.Message,), dict(
  DESCRIPTOR = _IDENTIFYDEVICERESPONSE,
  __module__ = 'devolo_idl_proto_plcnetapi_identifydevice_pb2'
  # @@protoc_insertion_point(class_scope:plcnet.api.IdentifyDeviceResponse)
  ))
_sym_db.RegisterMessage(IdentifyDeviceResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\006plcnetB\010identity'))
# @@protoc_insertion_point(module_scope)
